@@ -16,13 +16,39 @@
 #' @return Returns a list of objects of class \code{\link{nifti}},
 #' namely the inhomogeneity corrected FLAIR, T1, T2, and PD registered to the
 #' space of the T1 volume.
-#' @examples \dontrun{
+#' @examples 
 #' library(neurobase)
-#' flair <- readnii('path/to/flair', reorient = FALSE)
-#' t1 <- readnii('path/to/t1', reorient = FALSE)
-#' t2 <- readnii('path/to/t2', reorient = FALSE)
-#' pd <- readnii('path/to/pd', reorient = FALSE)
-#' oasis_preprocessed_data <- oasis_preproc(flair, t1, t2, pd)
+#' dl_file = function(url) {
+#'    tfile = tempfile(fileext = ".nii.gz")
+#'    req <- httr::GET(url,
+#'    httr::write_disk(path = tfile))
+#'    httr::stop_for_status(req)
+#'    tfile
+#' }
+#' in_ci <- function() {
+#'  nzchar(Sys.getenv("CI"))
+#' }
+#' on_cran = function() {
+#'  identical(Sys.getenv("NOT_CRAN"), "false")
+#' } 
+#' if (in_ci() || on_cran()) {
+#'   if (fslr::have.fsl() && require(httr)) {
+#'     mods = c("FLAIR", "T1W", "T2W", "consensus_gt", "brainmask")
+#'     base_url = file.path(
+#'       "https://raw.githubusercontent.com/muschellij2/open_ms_data", 
+#'       "master/cross_sectional/coregistered/patient01/")
+#'     files = paste0(base_url, mods, ".nii.gz")
+#'     files = sapply(files, dl_file)
+#'     names(files) = mods
+#' 
+#'     flair <- readnii(files["FLAIR"])
+#'     t1 <- readnii(files["T1W"])
+#'     t2 <- readnii(files["T2W"])
+#'     brain_mask <- readnii(files["brainmask"])
+#'     gold_standard = readnii(files["consensus_gt"])
+#'     oasis_preprocessed_data <- oasis_preproc(flair, t1, t2, 
+#'       brain_mask = brain_mask)
+#'   } 
 #' }
 #' @export
 #' @importFrom fslr flirt fslbet fsl_biascorrect
@@ -39,7 +65,6 @@ oasis_preproc <- function(flair, #flair volume of class nifti
 
 
   study <- list(flair = flair, t1 = t1, t2 = t2, pd = pd)
-  # study = check_nifti(study)
 
   # REMOVE NULL
   nulls = sapply(study, is.null)
@@ -70,8 +95,10 @@ oasis_preproc <- function(flair, #flair volume of class nifti
   brain_mask = check_nifti(brain_mask)
   brain_mask <- brain_mask > 0
   brain_mask <- datatyper(brain_mask, trybyte = TRUE)
-
-  study <- mclapply(study, mask_img, mask = brain_mask)
+  
+  study = check_nifti(study)
+  study <- mclapply(study, mask_img, mask = brain_mask, 
+                    mc.cores = cores)
 
   ## inhomogeneity correction for all four modalities using fsl bias correct
   if (verbose) {
